﻿using FccLite.Web.Repositories.FccOilInfo;
using FccLite.Web.Repositories.FccStationInfo;
using FccLite.Web.Services.FccOilInfo;
using FccLite.Web.Services.FccStaionInfo;
using FccLite.Web.utils.database;
using Microsoft.EntityFrameworkCore;

var builder = WebApplication.CreateBuilder(args);

//数据库
builder.Services.AddDbContext<MysqlDbContext>(options =>
    options.UseMySql(builder.Configuration.GetConnectionString("DefaultConnection"), ServerVersion.AutoDetect(builder.Configuration.GetConnectionString("DefaultConnection")))
    .LogTo(Console.WriteLine,LogLevel.Debug));

//controller
builder.Services.AddControllers();

//服务注册
builder.Services.AddScoped<IStationService, StationServiceImpl>();
builder.Services.AddScoped<IStationRepository, StationRepository>();
builder.Services.AddScoped<IOilInfoService, OilInfoServiceImpl>();
builder.Services.AddScoped<IOilInfoReposity, OilInfoReposity>();

//swagger
builder.Services.AddSwaggerGen(c =>
{
    c.SwaggerDoc("v1", new Microsoft.OpenApi.Models.OpenApiInfo
    {
        Title = ".NET 6.0 API",
        Version = "v1",
        Description = "二维码项目 FCC 页面接口",
    });
});
var app = builder.Build();

//controller
app.UseHttpsRedirection();
app.UseAuthorization();
app.MapControllers();

//swagger
app.UseSwagger();
app.UseSwaggerUI(c =>
{
    c.SwaggerEndpoint("/swagger/v1/swagger.json", ".NET 6 API V1");
});

//迁移数据库
//string? isMigrate = builder.Configuration.GetConnectionString("isMigrate");
//if (isMigrate != null && "true".Equals(isMigrate))
//{
//    //using var context = new MysqlDbContext();
//    //context.Database.Migrate();
//    using (var scope = app.Services.CreateScope())
//    {
//        var context = scope.ServiceProvider.GetRequiredService<MysqlDbContext>();
//        context.Database.Migrate();
//    }
//}

app.Run();
